@@ -1,8 +1,6 @@
 package Dist::Zilla::Plugin::PodWeaver;
-{
-  $Dist::Zilla::Plugin::PodWeaver::VERSION = '4.004';
-}
 # ABSTRACT: weave your Pod together from configuration and Dist::Zilla
+$Dist::Zilla::Plugin::PodWeaver::VERSION = '4.007';
 use Moose;
 use List::MoreUtils qw(any);
 use Pod::Weaver 3.100710; # logging with proxies
@@ -15,14 +13,52 @@ with(
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod [PodWeaver] is the bridge between L<Dist::Zilla> and L<Pod::Weaver>.  It rips
+#pod apart your kinda-Pod and reconstructs it as boring old real Pod.
+#pod
+#pod =head1 CONFIGURATION
+#pod
+#pod If the C<config_plugin> attribute is given, it will be treated like a
+#pod Pod::Weaver section heading.  For example, C<@Default> could be given.  It may
+#pod be given multiple times.
+#pod
+#pod Otherwise, if a file matching C<./weaver.*> exists, Pod::Weaver will be told to
+#pod look for configuration in the current directory.
+#pod
+#pod Otherwise, it will use the default configuration.
+#pod
+#pod =attr finder
+#pod
+#pod [PodWeaver] is a L<Dist::Zilla::Role::FileFinderUser>.  The L<FileFinder> given
+#pod for its C<finder> attribute is used to decide which files to munge.  By
+#pod default, it will munge:
+#pod
+#pod =for :list
+#pod * C<:InstallModules>
+#pod * C<:ExecFiles>
+#pod
+#pod =method weaver
+#pod
+#pod This method returns the Pod::Weaver object to be used.  The current
+#pod implementation builds a new weaver on each invocation, because one or two core
+#pod Pod::Weaver plugins cannot be trusted to handle multiple documents per plugin
+#pod instance.  In the future, when that is fixed, this may become an accessor of an
+#pod attribute with a builder.  Until this is clearer, use caution when modifying
+#pod this method in subclasses.
+#pod
+#pod =cut
 
 sub weaver {
   my ($self) = @_;
 
-  my @files = glob($self->zilla->root->file('weaver.*'));
+  my $root = $self->zilla->root->stringify;
+
+  my @files = glob("$root/weaver.*");
 
   my $arg = {
-      root        => $self->zilla->root,
+      root        => $root,
       root_config => { logger => $self->logger },
   };
 
@@ -40,8 +76,8 @@ sub weaver {
     return Pod::Weaver->new_from_config_sequence($assembler->sequence, $arg);
   } elsif (@files) {
     return Pod::Weaver->new_from_config(
-      { root   => $self->zilla->root },
-      { logger => $self->logger },
+      { root   => $root },
+      { root_config => { logger => $self->logger } },
     );
   } else {
     return Pod::Weaver->new_with_default_config($arg);
@@ -126,7 +162,6 @@ sub munge_perl_string {
 sub munge_pod {
   my ($self, $file) = @_;
 
-  my $content     = $file->encoded_content;
   my $new_content = $self->munge_perl_string(
     $file->content,
     {
@@ -144,7 +179,7 @@ sub munge_pod {
   return;
 }
 
-with 'Pod::Elemental::PerlMunger';
+with 'Pod::Elemental::PerlMunger' => { -version => 0.100000 };
 
 __PACKAGE__->meta->make_immutable;
 no Moose;
@@ -162,7 +197,7 @@ Dist::Zilla::Plugin::PodWeaver - weave your Pod together from configuration and
 
 =head1 VERSION
 
-version 4.004
+version 4.007
 
 =head1 DESCRIPTION
 
@@ -203,7 +238,7 @@ this method in subclasses.
 =head1 CONFIGURATION
 
 If the C<config_plugin> attribute is given, it will be treated like a
-Pod::Weaver section heading.  For example, C<@Default> could be given.  I may
+Pod::Weaver section heading.  For example, C<@Default> could be given.  It may
 be given multiple times.
 
 Otherwise, if a file matching C<./weaver.*> exists, Pod::Weaver will be told to
@@ -215,9 +250,37 @@ Otherwise, it will use the default configuration.
 
 Ricardo SIGNES <rjbs@cpan.org>
 
+=head1 CONTRIBUTORS
+
+=for stopwords David Golden Florian Ragwitz Karen Etheridge Yasutaka ATARASHI Сергей Романов
+
+=over 4
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Yasutaka ATARASHI <yakex@cpan.org>
+
+=item *
+
+Сергей Романов <sromanov-dev@yandex.ru>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
